@@ -116,6 +116,50 @@ Basic Usage
 	The best case scenario is if there is an idle thread waiting, in
 	which case delivery will be immediate.
 
+Advanced Usage - Logging
+========================
+
+	Additionally, you can configure your application to log TurboMail
+	events differently, in a more loggable and machine parsable way.
+	You do so by adding the following lines to the formatters section
+	of your log.cfg::
+	
+		[[[timed_message]]]
+		format='*(asctime)s *(message)s'
+	
+	Add the following to the handlers section of log.cfg::
+	
+		[[[mail_out]]]
+		class='StreamHandler'
+		level='INFO'
+		args='(sys.stdout,)'
+		formatter='timed_message'
+	
+	And finally, add the following to your dev.cfg::
+	
+		[[[mail]]]
+		level='INFO'
+		qualname='turbomail.dispatch'
+		handlers=['mail_out']
+		propagate=0
+	
+	If you wish to log mail dispatch to a file, for example in your
+	production configuration, use this instead of the above::
+	
+		[[handlers]]
+		[[[mail_out]]]
+		args="('mail.log',)"
+		class='StreamHandler'
+		level='INFO'
+		formatter='timed_message'
+		
+		[[loggers]]
+		[[[mail]]]
+		level='INFO'
+		qualname='turbomail.dispatch'
+		handlers=['mail_out']
+		propagate=0	
+
 Changelog
 =========
 
@@ -145,6 +189,13 @@ Changelog
 		 - Added encoding configuration directive.
 		 - Encoding can be passed to a Message constructor to override
 		   the encoding on a message-by-message basis.
+	
+	Version 1.1
+	-----------
+		 - Cleaned up the log output.
+		 - Added documentation for logging.
+		 - KID i18n session bug fixed in TurboGears 1.0 and trunk SVN.
+		 - Marked as stable for the Python Cheese Shop.
 		
 
 @var queue: After TurboGears startup within an application which has
