@@ -84,7 +84,7 @@ class Dispatch(object):
 		
 		if self.connected: return
 		
-		log.info("Connecting to SMTP server %s." % self.server)
+		log.debug("Connecting to SMTP server %s." % self.server)
 		self.connection.connect(self.server)
 
 		if self.tls or self.tls is None:
@@ -94,9 +94,11 @@ class Dispatch(object):
 				self.connection.starttls()
 				self.connection.ehlo()
 				log.debug("TLS enabled on SMTP server.")
+				self.tls = True
 			
 			else:
-				log.warn("TLS not available on SMTP server.")
+				log.debug("TLS not available on SMTP server.")
+				self.tls = False
 
 		if self.username and self.password:
 			log.debug("Authenticating as %s." % self.username)
@@ -128,7 +130,17 @@ class Dispatch(object):
 		
 		pack = message()
 		
-		log.info("\"%s\" >> \"%s\" :: \"%s\"" % (pack[0], pack[1], message._message['Subject']))
+		log.info(
+				'%(server)s %(user)s %(tls)s "%(addrfrom)s" "%(addrto)s" %(size)d "%(subject)s"' % dict(
+						user=['-', self.username][self.username and self.password],
+						server=self.server,
+						tls=['-', 'TLS'][self.tls],
+						addrfrom=pack[0],
+						addrto=pack[1],
+						size=len(pack[2]),
+						subject=message._message['Subject']
+					)
+			)
 		self.connection.sendmail(*pack)
 		
 		if self.debug: self.disconnect()
